CKEDITOR.plugins.setLang('youtube', 'he', {
	button : 'שבץ וידאו של YouTube',
	title : 'שבץ וידאו של YouTube',
	txtEmbed : 'הדבק את קוד השיבוץ כאן',
	txtUrl : 'הדבק כתובת וידאו YouTube',
	txtWidth : 'אורך',
	txtHeight : 'גובה',
	chkRelated : 'הצג סרטונים מומלצים בסוף הודיאו',
	txtStartAt : 'התחל ב (ss או mm:ss או hh:mm:ss)',
	chkPrivacy : 'הפעל מצב פרטיות המשופרת',
	chkOlderCode : 'השתמש בקוד הטמעה ישן',
	chkAutoplay: 'הפעלה אוטומטית',
	chkControls : 'הצג פקדי נגן',
	noCode : 'אתה חייב להזין קוד embed כתובת וידאו אתר',
	invalidEmbed : 'קוד ההטמעה שהוזן אינו נראה חוקי',
	invalidUrl : 'כתובת הוידאו אינה נראת חוקית',
	or : 'או',
	noWidth : 'חובה להזין אורך',
	invalidWidth : 'האורך שהוזן שגוי',
	noHeight : 'חובה להזין גובה',
	invalidHeight : 'הגובה שהוזן שגוי',
	invalidTime : 'זמן התחלה שהוזן שגוי',
	txtResponsive : 'הפוך לרספונסיבי (התעלם מרוחב וגובה, התאם לרוחב)'
});
