# Generated by Django 4.2 on 2023-06-02 13:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('blogs', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='post',
            name='visitor',
            field=models.IntegerField(default=0),
        ),
    ]
